tkmilan.spec
============

.. automodule:: tkmilan.spec

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      smvT
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      StaticMapLabels
      StaticMapValues
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Spec
      SpecCountable
      StaticList
      StaticMap
   
   

   
   
   



